/*
 * SWE Ereigniskalender - Version 2
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49-341-49067-0
 * Fax: +49-341-49067-15
 * E-Mail: info@bitctrl.de
 */

package de.bsvrz.vew.ereigniskal.data;

import java.time.Instant;
import java.time.LocalDateTime;
import java.time.ZoneId;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.Data.ReferenceArray;
import de.bsvrz.dav.daf.main.config.SystemObject;

/**
 * Kalenderanfrage, die aus den Daten einer Attributgruppe des Datenverteilers
 * gespeist wird.
 * 
 * @author BitCtrl Systems GmbH, Uwe Peuker
 */
public class DavKalenderAnfrage extends KalenderAnfrage {

    private SystemObject anfrager;
    private String zeichen;

    /**
     * erzeugt eine Anfrage aus den übergebenen Datenverteiler-Daten.
     * 
     * @param data
     *            die Daten
     */
    public DavKalenderAnfrage(Data data) {

        anfrager = data.getReferenceValue("absenderId").getSystemObject();
        zeichen = data.getTextValue("absenderZeichen").getText();
        setAnfangsZeitpunkt(LocalDateTime.ofInstant(
                Instant.ofEpochMilli(data.getTimeValue("Anfangszeitpunkt").getMillis()), ZoneId.systemDefault()));
        setEndZeitpunkt(LocalDateTime.ofInstant(Instant.ofEpochMilli(data.getTimeValue("Endzeitpunkt").getMillis()),
                ZoneId.systemDefault()));

        ReferenceArray raumArray = data.getReferenceArray("RäumlicheGültigkeit");
        for (int idx = 0; idx < raumArray.getLength(); idx++) {
            getRaeumlicheGueltigkeit().add(raumArray.getReferenceValue(idx).getSystemObject());
        }

        setEreignisTypOption(EreignisTypenOption.of(data.getUnscaledValue("EreignisTypenOption").intValue()));

        ReferenceArray ereignisTypArray = data.getReferenceArray("EreignisTypReferenz");
        for (int idx = 0; idx < ereignisTypArray.getLength(); idx++) {
            getEreignisTypen().add(ereignisTypArray.getReferenceValue(idx).getSystemObject());
        }
    }

    /**
     * liefert das Objekt des Anfragers (Applikations-Objekt), an den die
     * Antwort versendet werden soll.
     * 
     * @return das Systemobjekt
     */
    public SystemObject getAnfrager() {
        return anfrager;
    }

    /**
     * liefert die ID der Anfrage, dass in der Antwort als Identifikation
     * zurückgeschickt wird.
     * 
     * @return die ID
     */
    public String getZeichen() {
        return zeichen;
    }
}
