/*
 * SWE Ereigniskalender - Version 2
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49-341-49067-0
 * Fax: +49-341-49067-15
 * E-Mail: info@bitctrl.de
 */

package de.bsvrz.vew.ereigniskal.data;

/**
 * Definition der Typen eines Zeitbezugs bei der Beschreibung der verkehrlichen
 * Gültigkeit.
 * 
 * @author BitCtrl Systems GmbH, Uwe Peuker
 */
public enum ZeitBezug {
    /**
     * die verkehrliche Gültigkeit beginnt relativ vor dem Anfangszeitpunkt
     * eines zeitlichen Gültigkeitsbereiches.
     */
    vorAnfang(0),
    /**
     * die verkehrliche Gültigkeit beginnt relativ nach dem Anfangszeitpunkt
     * eines zeitlichen Gültigkeitsbereiches.
     */
    nachAnfang(1),
    /**
     * die verkehrliche Gültigkeit beginnt relativ vor dem Endzeitpunkt eines
     * zeitlichen Gültigkeitsbereiches.
     */
    vorEnde(2),
    /**
     * die verkehrliche Gültigkeit beginnt relativ nach dem Endzeitpunkt eines
     * zeitlichen Gültigkeitsbereiches.
     */
    nachEnde(3);

    /**
     * liefert den mit übergebenen Code verknüpften {@link ZeitBezug}.
     * 
     * @param code
     *            der Code
     * @return der Zeitbezug
     */
    public static ZeitBezug of(int code) {
        for (ZeitBezug bezug : values()) {
            if (bezug.code == code) {
                return bezug;
            }
        }
        throw new IllegalArgumentException("Ungültiger Zeitbezug: " + code);
    }

    private int code;

    ZeitBezug(int code) {
        this.code = code;
    }
}
