/*
 * SWE Ereigniskalender - Version 2
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49-341-49067-0
 * Fax: +49-341-49067-15
 * E-Mail: info@bitctrl.de
 */

package de.bsvrz.vew.ereigniskal.module;

import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

import de.bsvrz.dav.daf.main.ClientDavInterface;
import de.bsvrz.dav.daf.main.ClientReceiverInterface;
import de.bsvrz.dav.daf.main.DataDescription;
import de.bsvrz.dav.daf.main.ReceiveOptions;
import de.bsvrz.dav.daf.main.ReceiverRole;
import de.bsvrz.dav.daf.main.ResultData;
import de.bsvrz.dav.daf.main.config.ConfigurationObject;
import de.bsvrz.dav.daf.main.config.DataModel;
import de.bsvrz.vew.ereigniskal.data.DavKalenderAnfrage;

/**
 * Handler zur Bearbeitung anstehender Ereigiskalenderanfragen.
 * 
 * @author BitCtrl Systems GmbH, Uwe Peuker
 */
public class AnfrageHandler implements ClientReceiverInterface {

    private DataDescription anfrageDesc;

    private final ExecutorService anfragenBearbeiter = Executors.newCachedThreadPool();
    private EreignisVerwaltung ereignisVerwaltung;

    /**
     * start den Handler, der Anfragen zu dem übergebenen Kalender auf Basis der
     * zugeordneten Ereignisverwaltung über die angegebenen
     * Datenverteilerverbindung beantwortet.
     * 
     * @param dav
     *            die Datenverteilerverbindung
     * @param kalenderObj
     *            das betrachtete Kalenderobjekt
     * @param verwaltung
     *            die Ereignisverwaltung zur Bestimmung der Anfrage-Ergebnisse
     */
    public void run(ClientDavInterface dav, ConfigurationObject kalenderObj,
            EreignisVerwaltung verwaltung) {

        this.ereignisVerwaltung = verwaltung;

        DataModel model = dav.getDataModel();
        this.anfrageDesc = new DataDescription(model.getAttributeGroup("atg.ereignisKalenderAnfrage"),
                model.getAspect("asp.anfrage"));
        dav.subscribeReceiver(this, kalenderObj, anfrageDesc, ReceiveOptions.normal(), ReceiverRole.drain());
    }

    @Override
    public void update(ResultData[] results) {
        for (ResultData result : results) {
            if (result.hasData()) {
                DavKalenderAnfrage anfrage = new DavKalenderAnfrage(result.getData());
                anfragenBearbeiter.execute(new KalenderAnfrageBeantworter(anfrage, ereignisVerwaltung));
            }
        }
    }
}
